==> tdemultimedia-trinity-14.0.13.tar.xz: tdemultimedia-trinity-14.0.13/kaboodle/kaboodle_factory.h <==
/*****************************************************************

Copyright (c) 2000-2001 the noatun authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIAB\ILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef KABOODLE_FACTORY_H
#define KABOODLE_FACTORY_H

#include <tdeaboutdata.h>
#include <kinstance.h>
#include <tdeparts/factory.h>

namespace Kaboodle
{
class Player;

class KaboodleFactory : public KParts::Factory
{
Q_OBJECT
  

public:
	KaboodleFactory();
	virtual ~KaboodleFactory();

	virtual KParts::Part *createPartObject(TQWidget *widgetParent, const char *widgetName, TQObject *parent = 0, const char *name = 0, const char *classname = TQOBJECT_OBJECT_NAME_STRING, const TQStringList &args = TQStringList());

	static const TDEAboutData *aboutData();
	static TDEInstance *instance();
	
private:
	static TDEInstance *s_instance;
	static TDEAboutData *s_aboutData;
};

}

#endif

==> tdemultimedia-trinity_14.1.5.orig.tar.xz: tdemultimedia-trinity-14.1.5/kaboodle/kaboodle_factory.h <==
/*****************************************************************

Copyright (c) 2000-2001 the noatun authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIAB\ILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef KABOODLE_FACTORY_H
#define KABOODLE_FACTORY_H

#include <tdeaboutdata.h>
#include <tdeinstance.h>
#include <tdeparts/factory.h>

namespace Kaboodle
{
class Player;

class KaboodleFactory : public KParts::Factory
{
TQ_OBJECT
  

public:
	KaboodleFactory();
	virtual ~KaboodleFactory();

	virtual KParts::Part *createPartObject(TQWidget *widgetParent, const char *widgetName, TQObject *parent = 0, const char *name = 0, const char *classname = "TQObject", const TQStringList &args = TQStringList());

	static const TDEAboutData *aboutData();
	static TDEInstance *instance();
	
private:
	static TDEInstance *s_instance;
	static TDEAboutData *s_aboutData;
};

}

#endif
